package gssim.db.reader;

import java.io.IOException;
import java.text.NumberFormat;
import java.text.ParseException;

import simulator.GridSchedulingSimulator;

/**
 * 
 * @author Marcin Krystek
 * 
 */
public abstract class StatsReader {

	protected StatsParser parser;
	protected String[] values;

	protected NumberFormat format = GridSchedulingSimulator.DFAULT_NUMBER_FORMAT;

	public StatsReader(StatsParser p) {
		this.parser = p;
	}

	public boolean next() {
		try {
			this.values = parser.readValues();
			if (this.values != null)
				for (int i = 0; i < this.values.length; i++)
					this.values[i] = this.values[i].trim();
		} catch (IOException e) {
			e.printStackTrace();
			return false;
		}

		return (this.values != null);
	}

	protected double getAsDouble(int position) {
		try {
			double value = format.parse(values[position]).doubleValue();
			return value;
		} catch (ParseException e) {
			e.printStackTrace();
		}
		return -1;
	}

	protected float getAsFloat(int position) {
		try {
			float value = format.parse(values[position]).floatValue();
			return value;
		} catch (ParseException e) {
			e.printStackTrace();
		}
		return -1;
	}

	protected long getAsLong(int position) {
		try {
			long value = format.parse(values[position]).longValue();
			return value;
		} catch (ParseException e) {
			e.printStackTrace();
		}
		return -1;
	}

	protected int getAsInt(int position) {
		try {
			int value = format.parse(values[position]).intValue();
			return value;
		} catch (ParseException e) {
			e.printStackTrace();
		}
		return -1;
	}
}
